package Alien::mpg123;
our $AUTHORITY = 'cpan:GETTY';
# ABSTRACT: mpg123 music player
$Alien::mpg123::VERSION = '0.003';
use parent 'Alien::Base';

1;

__END__

=pod

=head1 NAME

Alien::mpg123 - mpg123 music player

=head1 VERSION

version 0.003

=head1 AUTHOR

Torsten Raudssus <torsten@raudss.us>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2013 by Torsten Raudssus.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
